import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { GetEarthObservationJobInput, GetEarthObservationJobOutput } from "../models/models_0";
import { SageMakerGeospatialClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../SageMakerGeospatialClient";
/**
 * @public
 *
 * The input for {@link GetEarthObservationJobCommand}.
 */
export interface GetEarthObservationJobCommandInput extends GetEarthObservationJobInput {
}
/**
 * @public
 *
 * The output of {@link GetEarthObservationJobCommand}.
 */
export interface GetEarthObservationJobCommandOutput extends GetEarthObservationJobOutput, __MetadataBearer {
}
/**
 * @public
 * <p>Get the details for a previously initiated Earth Observation job.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SageMakerGeospatialClient, GetEarthObservationJobCommand } from "@aws-sdk/client-sagemaker-geospatial"; // ES Modules import
 * // const { SageMakerGeospatialClient, GetEarthObservationJobCommand } = require("@aws-sdk/client-sagemaker-geospatial"); // CommonJS import
 * const client = new SageMakerGeospatialClient(config);
 * const input = { // GetEarthObservationJobInput
 *   Arn: "STRING_VALUE", // required
 * };
 * const command = new GetEarthObservationJobCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @param GetEarthObservationJobCommandInput - {@link GetEarthObservationJobCommandInput}
 * @returns {@link GetEarthObservationJobCommandOutput}
 * @see {@link GetEarthObservationJobCommandInput} for command's `input` shape.
 * @see {@link GetEarthObservationJobCommandOutput} for command's `response` shape.
 * @see {@link SageMakerGeospatialClientResolvedConfig | config} for SageMakerGeospatialClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception, or failure.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The request references a resource which does not exist.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The request was denied due to request throttling.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The input fails to satisfy the constraints specified by an Amazon Web Services service.</p>
 *
 *
 */
export declare class GetEarthObservationJobCommand extends $Command<GetEarthObservationJobCommandInput, GetEarthObservationJobCommandOutput, SageMakerGeospatialClientResolvedConfig> {
    readonly input: GetEarthObservationJobCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    /**
     * @public
     */
    constructor(input: GetEarthObservationJobCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: SageMakerGeospatialClientResolvedConfig, options?: __HttpHandlerOptions): Handler<GetEarthObservationJobCommandInput, GetEarthObservationJobCommandOutput>;
    /**
     * @internal
     */
    private serialize;
    /**
     * @internal
     */
    private deserialize;
}
